@@ -565,7 +565,7 @@ GType  bd_crypto_keyslot_context_get_type () {
     return type;
 }
 
-static gboolean  bd_crypto_is_tech_avail_stub (BDCryptoTech tech, guint64 mode, GError **error) {
+static gboolean  bd_crypto_is_tech_avail_stub (BDCryptoTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_is_tech_avail' called, but not implemented!");
@@ -612,7 +612,7 @@ gchar* bd_crypto_generate_backup_passphrase (GError **error) {
 }
 
 
-static gboolean  bd_crypto_device_is_luks_stub (const gchar *device, GError **error) {
+static gboolean  bd_crypto_device_is_luks_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_device_is_luks' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_device_is_luks' called, but not implemented!");
@@ -637,7 +637,7 @@ gboolean  bd_crypto_device_is_luks (const gchar *device, GError **error) {
 }
 
 
-static const gchar* bd_crypto_luks_status_stub (const gchar *luks_device, GError **error) {
+static const gchar* bd_crypto_luks_status_stub (const gchar *luks_device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_status' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_status' called, but not implemented!");
@@ -662,7 +662,7 @@ const gchar* bd_crypto_luks_status (const gchar *luks_device, GError **error) {
 }
 
 
-static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_passphrase_stub (const guint8 *pass_data, gsize data_len, GError **error) {
+static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_passphrase_stub (const guint8 *pass_data G_GNUC_UNUSED, gsize data_len G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_keyslot_context_new_passphrase' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_keyslot_context_new_passphrase' called, but not implemented!");
@@ -687,7 +687,7 @@ BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_passphrase (const guint8 *
 }
 
 
-static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_keyfile_stub (const gchar *keyfile, guint64 keyfile_offset, gsize key_size, GError **error) {
+static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_keyfile_stub (const gchar *keyfile G_GNUC_UNUSED, guint64 keyfile_offset G_GNUC_UNUSED, gsize key_size G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_keyslot_context_new_keyfile' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_keyslot_context_new_keyfile' called, but not implemented!");
@@ -713,7 +713,7 @@ BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_keyfile (const gchar *keyf
 }
 
 
-static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_keyring_stub (const gchar *key_desc, GError **error) {
+static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_keyring_stub (const gchar *key_desc G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_keyslot_context_new_keyring' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_keyslot_context_new_keyring' called, but not implemented!");
@@ -740,7 +740,7 @@ BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_keyring (const gchar *key_
 }
 
 
-static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_volume_key_stub (const guint8 *volume_key, gsize volume_key_size, GError **error) {
+static BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_volume_key_stub (const guint8 *volume_key G_GNUC_UNUSED, gsize volume_key_size G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_keyslot_context_new_volume_key' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_keyslot_context_new_volume_key' called, but not implemented!");
@@ -765,7 +765,7 @@ BDCryptoKeyslotContext* bd_crypto_keyslot_context_new_volume_key (const guint8 *
 }
 
 
-static gboolean  bd_crypto_luks_format_stub (const gchar *device, const gchar *cipher, guint64 key_size, BDCryptoKeyslotContext *context, guint64 min_entropy, BDCryptoLUKSVersion luks_version, BDCryptoLUKSExtra *extra,GError **error) {
+static gboolean  bd_crypto_luks_format_stub (const gchar *device G_GNUC_UNUSED, const gchar *cipher G_GNUC_UNUSED, guint64 key_size G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, guint64 min_entropy G_GNUC_UNUSED, BDCryptoLUKSVersion luks_version G_GNUC_UNUSED, BDCryptoLUKSExtra *extra G_GNUC_UNUSED,GError **error) {
     g_critical ("The function 'bd_crypto_luks_format' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_format' called, but not implemented!");
@@ -802,7 +802,7 @@ gboolean  bd_crypto_luks_format (const gchar *device, const gchar *cipher, guint
 }
 
 
-static gboolean  bd_crypto_luks_open_stub (const gchar *device, const gchar *name, BDCryptoKeyslotContext *context, gboolean read_only, GError **error) {
+static gboolean  bd_crypto_luks_open_stub (const gchar *device G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, gboolean read_only G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_open' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_open' called, but not implemented!");
@@ -839,7 +839,7 @@ gboolean  bd_crypto_luks_open (const gchar *device, const gchar *name, BDCryptoK
 }
 
 
-static gboolean  bd_crypto_luks_close_stub (const gchar *luks_device, GError **error) {
+static gboolean  bd_crypto_luks_close_stub (const gchar *luks_device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_close' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_close' called, but not implemented!");
@@ -862,7 +862,7 @@ gboolean  bd_crypto_luks_close (const gchar *luks_device, GError **error) {
 }
 
 
-static gboolean  bd_crypto_luks_add_key_stub (const gchar *device, BDCryptoKeyslotContext *context, BDCryptoKeyslotContext *ncontext, GError **error) {
+static gboolean  bd_crypto_luks_add_key_stub (const gchar *device G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, BDCryptoKeyslotContext *ncontext G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_add_key' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_add_key' called, but not implemented!");
@@ -890,7 +890,7 @@ gboolean  bd_crypto_luks_add_key (const gchar *device, BDCryptoKeyslotContext *c
 }
 
 
-static gboolean  bd_crypto_luks_remove_key_stub (const gchar *device, BDCryptoKeyslotContext *context, GError **error) {
+static gboolean  bd_crypto_luks_remove_key_stub (const gchar *device G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_remove_key' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_remove_key' called, but not implemented!");
@@ -916,7 +916,7 @@ gboolean  bd_crypto_luks_remove_key (const gchar *device, BDCryptoKeyslotContext
 }
 
 
-static gboolean  bd_crypto_luks_change_key_stub (const gchar *device, BDCryptoKeyslotContext *context, BDCryptoKeyslotContext *ncontext, GError **error) {
+static gboolean  bd_crypto_luks_change_key_stub (const gchar *device G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, BDCryptoKeyslotContext *ncontext G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_change_key' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_change_key' called, but not implemented!");
@@ -943,7 +943,7 @@ gboolean  bd_crypto_luks_change_key (const gchar *device, BDCryptoKeyslotContext
 }
 
 
-static gboolean  bd_crypto_luks_resize_stub (const gchar *luks_device, guint64 size, BDCryptoKeyslotContext *context, GError **error) {
+static gboolean  bd_crypto_luks_resize_stub (const gchar *luks_device G_GNUC_UNUSED, guint64 size G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_resize' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_resize' called, but not implemented!");
@@ -974,7 +974,7 @@ gboolean  bd_crypto_luks_resize (const gchar *luks_device, guint64 size, BDCrypt
 }
 
 
-static gboolean  bd_crypto_luks_suspend_stub (const gchar *luks_device, GError **error) {
+static gboolean  bd_crypto_luks_suspend_stub (const gchar *luks_device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_suspend' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_suspend' called, but not implemented!");
@@ -997,7 +997,7 @@ gboolean  bd_crypto_luks_suspend (const gchar *luks_device, GError **error) {
 }
 
 
-static gboolean  bd_crypto_luks_resume_stub (const gchar *luks_device, BDCryptoKeyslotContext *context, GError **error) {
+static gboolean  bd_crypto_luks_resume_stub (const gchar *luks_device G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_resume' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_resume' called, but not implemented!");
@@ -1023,7 +1023,7 @@ gboolean  bd_crypto_luks_resume (const gchar *luks_device, BDCryptoKeyslotContex
 }
 
 
-static gboolean  bd_crypto_luks_kill_slot_stub (const gchar *device, gint slot, GError **error) {
+static gboolean  bd_crypto_luks_kill_slot_stub (const gchar *device G_GNUC_UNUSED, gint slot G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_kill_slot' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_kill_slot' called, but not implemented!");
@@ -1050,7 +1050,7 @@ gboolean  bd_crypto_luks_kill_slot (const gchar *device, gint slot, GError **err
 }
 
 
-static gboolean  bd_crypto_luks_header_backup_stub (const gchar *device, const gchar *backup_file, GError **error) {
+static gboolean  bd_crypto_luks_header_backup_stub (const gchar *device G_GNUC_UNUSED, const gchar *backup_file G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_header_backup' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_header_backup' called, but not implemented!");
@@ -1075,7 +1075,7 @@ gboolean  bd_crypto_luks_header_backup (const gchar *device, const gchar *backup
 }
 
 
-static gboolean  bd_crypto_luks_header_restore_stub (const gchar *device, const gchar *backup_file, GError **error) {
+static gboolean  bd_crypto_luks_header_restore_stub (const gchar *device G_GNUC_UNUSED, const gchar *backup_file G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_header_restore' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_header_restore' called, but not implemented!");
@@ -1101,7 +1101,7 @@ gboolean  bd_crypto_luks_header_restore (const gchar *device, const gchar *backu
 }
 
 
-static gboolean  bd_crypto_luks_set_label_stub (const gchar *device, const gchar *label, const gchar *subsystem, GError **error) {
+static gboolean  bd_crypto_luks_set_label_stub (const gchar *device G_GNUC_UNUSED, const gchar *label G_GNUC_UNUSED, const gchar *subsystem G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_set_label' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_set_label' called, but not implemented!");
@@ -1126,7 +1126,7 @@ gboolean  bd_crypto_luks_set_label (const gchar *device, const gchar *label, con
 }
 
 
-static gboolean  bd_crypto_luks_set_uuid_stub (const gchar *device, const gchar *uuid, GError **error) {
+static gboolean  bd_crypto_luks_set_uuid_stub (const gchar *device G_GNUC_UNUSED, const gchar *uuid G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_set_uuid' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_set_uuid' called, but not implemented!");
@@ -1150,7 +1150,7 @@ gboolean  bd_crypto_luks_set_uuid (const gchar *device, const gchar *uuid, GErro
 }
 
 
-static BDCryptoLUKSInfo* bd_crypto_luks_info_stub (const gchar *device, GError **error) {
+static BDCryptoLUKSInfo* bd_crypto_luks_info_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_info' called, but not implemented!");
@@ -1173,7 +1173,7 @@ BDCryptoLUKSInfo* bd_crypto_luks_info (const gchar *device, GError **error) {
 }
 
 
-static BDCryptoBITLKInfo* bd_crypto_bitlk_info_stub (const gchar *device, GError **error) {
+static BDCryptoBITLKInfo* bd_crypto_bitlk_info_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_bitlk_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_bitlk_info' called, but not implemented!");
@@ -1196,7 +1196,7 @@ BDCryptoBITLKInfo* bd_crypto_bitlk_info (const gchar *device, GError **error) {
 }
 
 
-static BDCryptoIntegrityInfo* bd_crypto_integrity_info_stub (const gchar *device, GError **error) {
+static BDCryptoIntegrityInfo* bd_crypto_integrity_info_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_integrity_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_integrity_info' called, but not implemented!");
@@ -1219,7 +1219,7 @@ BDCryptoIntegrityInfo* bd_crypto_integrity_info (const gchar *device, GError **e
 }
 
 
-static BDCryptoLUKSTokenInfo** bd_crypto_luks_token_info_stub (const gchar *device, GError **error) {
+static BDCryptoLUKSTokenInfo** bd_crypto_luks_token_info_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_luks_token_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_luks_token_info' called, but not implemented!");
@@ -1242,7 +1242,7 @@ BDCryptoLUKSTokenInfo** bd_crypto_luks_token_info (const gchar *device, GError *
 }
 
 
-static gboolean  bd_crypto_integrity_format_stub (const gchar *device, const gchar *algorithm, gboolean wipe, BDCryptoKeyslotContext *context, BDCryptoIntegrityExtra *extra, GError **error) {
+static gboolean  bd_crypto_integrity_format_stub (const gchar *device G_GNUC_UNUSED, const gchar *algorithm G_GNUC_UNUSED, gboolean wipe G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, BDCryptoIntegrityExtra *extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_integrity_format' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_integrity_format' called, but not implemented!");
@@ -1274,7 +1274,7 @@ gboolean  bd_crypto_integrity_format (const gchar *device, const gchar *algorith
 }
 
 
-static gboolean  bd_crypto_integrity_open_stub (const gchar *device, const gchar *name, const gchar *algorithm, BDCryptoKeyslotContext *context, BDCryptoIntegrityOpenFlags flags, BDCryptoIntegrityExtra *extra, GError **error) {
+static gboolean  bd_crypto_integrity_open_stub (const gchar *device G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, const gchar *algorithm G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, BDCryptoIntegrityOpenFlags flags G_GNUC_UNUSED, BDCryptoIntegrityExtra *extra G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_integrity_open' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_integrity_open' called, but not implemented!");
@@ -1304,7 +1304,7 @@ gboolean  bd_crypto_integrity_open (const gchar *device, const gchar *name, cons
 }
 
 
-static gboolean  bd_crypto_integrity_close_stub (const gchar *integrity_device, GError **error) {
+static gboolean  bd_crypto_integrity_close_stub (const gchar *integrity_device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_integrity_close' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_integrity_close' called, but not implemented!");
@@ -1327,7 +1327,7 @@ gboolean  bd_crypto_integrity_close (const gchar *integrity_device, GError **err
 }
 
 
-static gboolean  bd_crypto_keyring_add_key_stub (const gchar *key_desc, const guint8 *key_data, gsize data_len, GError **error) {
+static gboolean  bd_crypto_keyring_add_key_stub (const gchar *key_desc G_GNUC_UNUSED, const guint8 *key_data G_GNUC_UNUSED, gsize data_len G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_keyring_add_key' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_keyring_add_key' called, but not implemented!");
@@ -1352,7 +1352,7 @@ gboolean  bd_crypto_keyring_add_key (const gchar *key_desc, const guint8 *key_da
 }
 
 
-static gboolean  bd_crypto_device_seems_encrypted_stub (const gchar *device, GError **error) {
+static gboolean  bd_crypto_device_seems_encrypted_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_device_seems_encrypted' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_device_seems_encrypted' called, but not implemented!");
@@ -1389,7 +1389,7 @@ gboolean  bd_crypto_device_seems_encrypted (const gchar *device, GError **error)
 }
 
 
-static gboolean  bd_crypto_tc_open_stub (const gchar *device, const gchar *name, BDCryptoKeyslotContext *context, const gchar **keyfiles, gboolean hidden, gboolean system, gboolean veracrypt, guint32 veracrypt_pim, gboolean read_only, GError **error) {
+static gboolean  bd_crypto_tc_open_stub (const gchar *device G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, const gchar **keyfiles G_GNUC_UNUSED, gboolean hidden G_GNUC_UNUSED, gboolean system G_GNUC_UNUSED, gboolean veracrypt G_GNUC_UNUSED, guint32 veracrypt_pim G_GNUC_UNUSED, gboolean read_only G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_tc_open' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_tc_open' called, but not implemented!");
@@ -1422,7 +1422,7 @@ gboolean  bd_crypto_tc_open (const gchar *device, const gchar *name, BDCryptoKey
 }
 
 
-static gboolean  bd_crypto_tc_close_stub (const gchar *tc_device, GError **error) {
+static gboolean  bd_crypto_tc_close_stub (const gchar *tc_device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_tc_close' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_tc_close' called, but not implemented!");
@@ -1445,7 +1445,7 @@ gboolean  bd_crypto_tc_close (const gchar *tc_device, GError **error) {
 }
 
 
-static gboolean  bd_crypto_escrow_device_stub (const gchar *device, const gchar *passphrase, const gchar *cert_data, const gchar *directory, const gchar *backup_passphrase, GError **error) {
+static gboolean  bd_crypto_escrow_device_stub (const gchar *device G_GNUC_UNUSED, const gchar *passphrase G_GNUC_UNUSED, const gchar *cert_data G_GNUC_UNUSED, const gchar *directory G_GNUC_UNUSED, const gchar *backup_passphrase G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_escrow_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_escrow_device' called, but not implemented!");
@@ -1472,7 +1472,7 @@ gboolean  bd_crypto_escrow_device (const gchar *device, const gchar *passphrase,
 }
 
 
-static gboolean  bd_crypto_bitlk_open_stub (const gchar *device, const gchar *name, BDCryptoKeyslotContext *context, gboolean read_only, GError **error) {
+static gboolean  bd_crypto_bitlk_open_stub (const gchar *device G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, gboolean read_only G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_bitlk_open' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_bitlk_open' called, but not implemented!");
@@ -1500,7 +1500,7 @@ gboolean  bd_crypto_bitlk_open (const gchar *device, const gchar *name, BDCrypto
 }
 
 
-static gboolean  bd_crypto_bitlk_close_stub (const gchar *bitlk_device, GError **error) {
+static gboolean  bd_crypto_bitlk_close_stub (const gchar *bitlk_device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_bitlk_close' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_bitlk_close' called, but not implemented!");
@@ -1523,7 +1523,7 @@ gboolean  bd_crypto_bitlk_close (const gchar *bitlk_device, GError **error) {
 }
 
 
-static gboolean  bd_crypto_fvault2_open_stub (const gchar *device, const gchar *name, BDCryptoKeyslotContext *context, gboolean read_only, GError **error) {
+static gboolean  bd_crypto_fvault2_open_stub (const gchar *device G_GNUC_UNUSED, const gchar *name G_GNUC_UNUSED, BDCryptoKeyslotContext *context G_GNUC_UNUSED, gboolean read_only G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_fvault2_open' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_fvault2_open' called, but not implemented!");
@@ -1551,7 +1551,7 @@ gboolean  bd_crypto_fvault2_open (const gchar *device, const gchar *name, BDCryp
 }
 
 
-static gboolean  bd_crypto_fvault2_close_stub (const gchar *fvault2_device, GError **error) {
+static gboolean  bd_crypto_fvault2_close_stub (const gchar *fvault2_device G_GNUC_UNUSED, GError **error) {
     g_critical ("The function 'bd_crypto_fvault2_close' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_crypto_fvault2_close' called, but not implemented!");
