@@ -11,10 +11,14 @@
 
 /**
  * bd_plugin_spec_copy: (skip)
+ * @spec: (nullable): %BDPluginSpec to copy
  *
  * Creates a new copy of @spec.
  */
 BDPluginSpec* bd_plugin_spec_copy (BDPluginSpec *spec) {
+    if (!spec)
+        return NULL;
+
     BDPluginSpec *new_spec = g_new0 (BDPluginSpec, 1);
 
     new_spec->name = spec->name;
@@ -25,10 +29,13 @@ BDPluginSpec* bd_plugin_spec_copy (BDPluginSpec *spec) {
 
 /**
  * bd_plugin_spec_free: (skip)
+ * @spec: (nullable): %BDPluginSpec to free
  *
  * Frees @spec.
  */
 void bd_plugin_spec_free (BDPluginSpec *spec) {
+    if (!spec)
+        return;
     g_free ((gchar *) spec->so_name);
     g_free (spec);
 }
