@@ -51,17 +51,29 @@ static const UtilDep deps[DEPS_LAST] = {
 };
 
 static guint32 fs_mode_util[BD_FS_MODE_LAST+1] = {
-    /*   mkfs          wipe     check               repair                set-label            query                resize */
-    DEPS_MKFSXFS_MASK,  0, DEPS_XFS_DB_MASK,   DEPS_XFS_REPAIR_MASK, DEPS_XFS_ADMIN_MASK, DEPS_XFS_ADMIN_MASK, DEPS_XFS_GROWFS_MASK
+    DEPS_MKFSXFS_MASK,      /* mkfs */
+    0,                      /* wipe */
+    DEPS_XFS_DB_MASK,       /* check */
+    DEPS_XFS_REPAIR_MASK,   /* repair */
+    DEPS_XFS_ADMIN_MASK,    /* set-label */
+    DEPS_XFS_ADMIN_MASK,    /* query */
+    DEPS_XFS_GROWFS_MASK,   /* resize */
+    DEPS_XFS_ADMIN_MASK     /* set-uuid */
 };
 
 #define UNUSED __attribute__((unused))
 
+#ifdef __clang__
+#define ZERO_INIT {}
+#else
+#define ZERO_INIT {0}
+#endif
+
 /**
  * bd_fs_xfs_is_tech_avail:
  * @tech: the queried tech
  * @mode: a bit mask of queried modes of operation (#BDFSTechMode) for @tech
- * @error: (out): place to store error (details about why the @tech-@mode combination is not available)
+ * @error: (out) (optional): place to store error (details about why the @tech-@mode combination is not available)
  *
  * Returns: whether the @tech-@mode combination is available -- supported by the
  *          plugin implementation and having all the runtime dependencies available
@@ -110,13 +122,47 @@ void bd_fs_xfs_info_free (BDFSXfsInfo *data) {
     g_free (data);
 }
 
+BDExtraArg __attribute__ ((visibility ("hidden")))
+**bd_fs_xfs_mkfs_options (BDFSMkfsOptions *options, const BDExtraArg **extra) {
+    GPtrArray *options_array = g_ptr_array_new ();
+    const BDExtraArg **extra_p = NULL;
+    gchar *uuid_option = NULL;
+
+    if (options->label && g_strcmp0 (options->label, "") != 0)
+        g_ptr_array_add (options_array, bd_extra_arg_new ("-L", options->label));
+
+    if (options->uuid && g_strcmp0 (options->uuid, "") != 0) {
+        uuid_option = g_strdup_printf ("uuid=%s", options->uuid);
+        g_ptr_array_add (options_array, bd_extra_arg_new ("-m", uuid_option));
+        g_free (uuid_option);
+    }
+
+    if (options->dry_run)
+        g_ptr_array_add (options_array, bd_extra_arg_new ("-N", ""));
+
+    if (options->no_discard)
+        g_ptr_array_add (options_array, bd_extra_arg_new ("-K", ""));
+
+    if (options->force)
+        g_ptr_array_add (options_array, bd_extra_arg_new ("-f", ""));
+
+    if (extra) {
+        for (extra_p = extra; *extra_p; extra_p++)
+            g_ptr_array_add (options_array, bd_extra_arg_copy ((BDExtraArg *) *extra_p));
+    }
+
+    g_ptr_array_add (options_array, NULL);
+
+    return (BDExtraArg **) g_ptr_array_free (options_array, FALSE);
+}
+
 
 /**
  * bd_fs_xfs_mkfs:
  * @device: the device to create a new xfs fs on
- * @extra: (allow-none) (array zero-terminated=1): extra options for the creation (right now
+ * @extra: (nullable) (array zero-terminated=1): extra options for the creation (right now
  *                                                 passed to the 'mkfs.xfs' utility)
- * @error: (out): place to store error (if any)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: whether a new xfs fs was successfully created on @device or not
  *
@@ -131,24 +177,12 @@ gboolean bd_fs_xfs_mkfs (const gchar *device, const BDExtraArg **extra, GError *
     return bd_utils_exec_and_report_error (args, extra, error);
 }
 
-/**
- * bd_fs_xfs_wipe:
- * @device: the device to wipe an xfs signature from
- * @error: (out): place to store error (if any)
- *
- * Returns: whether an xfs signature was successfully wiped from the @device or
- *          not
- *
- * Tech category: %BD_FS_TECH_XFS-%BD_FS_TECH_MODE_WIPE
- */
-gboolean bd_fs_xfs_wipe (const gchar *device, GError **error) {
-    return wipe_fs (device, "xfs", FALSE, error);
-}
-
 /**
  * bd_fs_xfs_check:
  * @device: the device containing the file system to check
- * @error: (out): place to store error (if any)
+ * @extra: (nullable) (array zero-terminated=1): extra options for the repair (right now
+ *                                               passed to the 'xfs_repair' utility)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: whether an xfs file system on the @device is clean or not
  *
@@ -157,27 +191,32 @@ gboolean bd_fs_xfs_wipe (const gchar *device, GError **error) {
  *
  * Tech category: %BD_FS_TECH_XFS-%BD_FS_TECH_MODE_CHECK
  */
-gboolean bd_fs_xfs_check (const gchar *device, GError **error) {
+gboolean bd_fs_xfs_check (const gchar *device, const BDExtraArg **extra, GError **error) {
     const gchar *args[4] = {"xfs_repair", "-n", device, NULL};
     gboolean ret = FALSE;
+    GError *l_error = NULL;
 
     if (!check_deps (&avail_deps, DEPS_XFS_REPAIR_MASK, deps, DEPS_LAST, &deps_check_lock, error))
         return FALSE;
 
-    ret = bd_utils_exec_and_report_error (args, NULL, error);
-    if (!ret && *error &&  g_error_matches ((*error), BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_FAILED))
-        /* non-zero exit status -> the fs is not clean, but not an error */
-        /* TODO: should we check that the device exists and contains an XFS FS beforehand? */
-        g_clear_error (error);
+    ret = bd_utils_exec_and_report_error (args, extra, &l_error);
+    if (!ret) {
+        if (l_error && g_error_matches (l_error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_FAILED)) {
+            /* non-zero exit status -> the fs is not clean, but not an error */
+            /* TODO: should we check that the device exists and contains an XFS FS beforehand? */
+            g_clear_error (&l_error);
+        } else
+            g_propagate_error (error, l_error);
+    }
     return ret;
 }
 
 /**
  * bd_fs_xfs_repair:
  * @device: the device containing the file system to repair
- * @extra: (allow-none) (array zero-terminated=1): extra options for the repair (right now
+ * @extra: (nullable) (array zero-terminated=1): extra options for the repair (right now
  *                                                 passed to the 'xfs_repair' utility)
- * @error: (out): place to store error (if any)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: whether an xfs file system on the @device was successfully repaired
  *          (if needed) or not (error is set in that case)
@@ -197,7 +236,7 @@ gboolean bd_fs_xfs_repair (const gchar *device, const BDExtraArg **extra, GError
  * bd_fs_xfs_set_label:
  * @device: the device containing the file system to set label for
  * @label: label to set
- * @error: (out): place to store error (if any)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: whether the label of xfs file system on the @device was
  *          successfully set or not
@@ -215,12 +254,77 @@ gboolean bd_fs_xfs_set_label (const gchar *device, const gchar *label, GError **
     return bd_utils_exec_and_report_error (args, NULL, error);
 }
 
+/**
+ * bd_fs_xfs_check_label:
+ * @label: label to check
+ * @error: (out) (optional): place to store error
+ *
+ * Returns: whether @label is a valid label for the xfs file system or not
+ *          (reason is provided in @error)
+ *
+ * Tech category: always available
+ */
+gboolean bd_fs_xfs_check_label (const gchar *label, GError **error) {
+    size_t len = 0;
+
+    len = strlen (label);
+    if (len > 12) {
+        g_set_error (error, BD_FS_ERROR, BD_FS_ERROR_LABEL_INVALID,
+                     "Label for XFS filesystem must be at most 12 characters long.");
+        return FALSE;
+    }
+
+    if (strchr (label, ' ') != NULL) {
+        g_set_error (error, BD_FS_ERROR, BD_FS_ERROR_LABEL_INVALID,
+                     "Label for XFS filesystem cannot contain spaces.");
+        return FALSE;
+    }
+
+    return TRUE;
+}
+
+/**
+ * bd_fs_xfs_set_uuid:
+ * @device: the device containing the file system to set uuid for
+ * @uuid: (nullable): UUID to set %NULL to generate a new one
+ *                      UUID can also be one of "nil" and "generate" to clear or
+ *                      generate a new UUID
+ * @error: (out) (optional): place to store error (if any)
+ *
+ * Returns: whether the UUID of xfs file system on the @device was
+ *          successfully set or not
+ *
+ * Tech category: %BD_FS_TECH_XFS-%BD_FS_TECH_MODE_SET_UUID
+ */
+gboolean bd_fs_xfs_set_uuid (const gchar *device, const gchar *uuid, GError **error) {
+    const gchar *args[5] = {"xfs_admin", "-U", uuid, device, NULL};
+    if (!uuid)
+        args[2] = "generate";
+
+    if (!check_deps (&avail_deps, DEPS_XFS_ADMIN_MASK, deps, DEPS_LAST, &deps_check_lock, error))
+        return FALSE;
+
+    return bd_utils_exec_and_report_error (args, NULL, error);
+}
+
+/**
+ * bd_fs_xfs_check_uuid:
+ * @uuid: UUID to check
+ * @error: (out) (optional): place to store error
+ *
+ * Returns: whether @uuid is a valid UUID for the xfs file system or not
+ *          (reason is provided in @error)
+ *
+ * Tech category: always available
+ */
+gboolean bd_fs_xfs_check_uuid (const gchar *uuid, GError **error) {
+    return check_uuid (uuid, error);
+}
+
 /**
  * bd_fs_xfs_get_info:
- * @device: the device containing the file system to get info for (device must
-            be mounted, trying to get info for an unmounted device will result
-            in an error)
- * @error: (out): place to store error (if any)
+ * @device: the device containing the file system to get info for
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: (transfer full): information about the file system on @device or
  *                           %NULL in case of error
@@ -228,68 +332,56 @@ gboolean bd_fs_xfs_set_label (const gchar *device, const gchar *label, GError **
  * Tech category: %BD_FS_TECH_XFS-%BD_FS_TECH_MODE_QUERY
  */
 BDFSXfsInfo* bd_fs_xfs_get_info (const gchar *device, GError **error) {
-    const gchar *args[4] = {"xfs_admin", "-lu", device, NULL};
+    const gchar *args[6] = ZERO_INIT;
     gboolean success = FALSE;
     gchar *output = NULL;
     BDFSXfsInfo *ret = NULL;
     gchar **lines = NULL;
     gchar **line_p = NULL;
-    gboolean have_label = FALSE;
-    gboolean have_uuid = FALSE;
     gchar *val_start = NULL;
-    gchar *val_end = NULL;
     g_autofree gchar* mountpoint = NULL;
 
     if (!check_deps (&avail_deps, DEPS_XFS_ADMIN_MASK, deps, DEPS_LAST, &deps_check_lock, error))
-        return FALSE;
-
-    mountpoint = bd_fs_get_mountpoint (device, error);
-    if (mountpoint == NULL) {
-        if (error != NULL && *error == NULL) {
-            g_set_error (error, BD_FS_ERROR, BD_FS_ERROR_NOT_MOUNTED,
-                         "Can't get xfs file system information for '%s': Device is not mounted.", device);
-            return NULL;
-        } else {
-            g_prefix_error (error, "Error when trying to get mountpoint for '%s': ", device);
-            return NULL;
-        }
-    }
-
-    success = bd_utils_exec_and_capture_output (args, NULL, &output, error);
-    if (!success)
-        /* error is already populated */
-        return FALSE;
+        return NULL;
 
     ret = g_new0 (BDFSXfsInfo, 1);
-    lines = g_strsplit (output, "\n", 0);
-    g_free (output);
-    for (line_p=lines; line_p && *line_p && (!have_label || !have_uuid); line_p++) {
-        if (!have_label && g_str_has_prefix (*line_p, "label")) {
-            /* extract label from something like this: label = "TEST_LABEL" */
-            val_start = strchr (*line_p, '"');
-            if (val_start)
-                val_end = strchr(val_start + 1, '"');
-            if (val_start && val_end) {
-                ret->label = g_strndup (val_start + 1, val_end - val_start - 1);
-                have_label = TRUE;
-            }
-        } else if (!have_uuid && g_str_has_prefix (*line_p, "UUID")) {
-            /* get right after the "UUID = " prefix */
-            val_start = *line_p + 7;
-            ret->uuid = g_strdup (val_start);
-            have_uuid = TRUE;
-        }
-    }
-    g_strfreev (lines);
 
-    args[0] = "xfs_info";
-    args[1] = mountpoint;
-    args[2] = NULL;
+    success = get_uuid_label (device, &(ret->uuid), &(ret->label), error);
+    if (!success) {
+        /* error is already populated */
+        bd_fs_xfs_info_free (ret);
+        return NULL;
+    }
+
+    /* It is important to use xfs_spaceman for a mounted filesystem
+       since xfs_db might return old information.  xfs_info would be
+       able to do the job for us (running xfs_spaceman or xfs_db
+       depending on whether the fs is mounted), but it doesn't pass
+       "-r" to xfs_db, which is important to avoid spurious udev
+       events just for reading information.
+    */
+
+    mountpoint = bd_fs_get_mountpoint (device, NULL);
+    if (mountpoint) {
+      args[0] = "xfs_spaceman";
+      args[1] = "-c";
+      args[2] = "info";
+      args[3] = mountpoint;
+      args[4] = NULL;
+    } else {
+      args[0] = "xfs_db";
+      args[1] = "-r";
+      args[2] = "-c";
+      args[3] = "info";
+      args[4] = device;
+      args[5] = NULL;
+    }
+
     success = bd_utils_exec_and_capture_output (args, NULL, &output, error);
     if (!success) {
         /* error is already populated */
         bd_fs_xfs_info_free (ret);
-        return FALSE;
+        return NULL;
     }
 
     lines = g_strsplit (output, "\n", 0);
@@ -299,11 +391,10 @@ BDFSXfsInfo* bd_fs_xfs_get_info (const gchar *device, GError **error) {
     while (line_p && *line_p && !g_str_has_prefix (*line_p, "data"))
         line_p++;
     if (!line_p || !(*line_p)) {
-        /* error is already populated */
         g_set_error (error, BD_FS_ERROR, BD_FS_ERROR_PARSE, "Failed to parse xfs file system information");
         g_strfreev (lines);
         bd_fs_xfs_info_free (ret);
-        return FALSE;
+        return NULL;
     }
 
     /* extract data from something like this: "data     =      bsize=4096   blocks=262400, imaxpct=25" */
@@ -316,11 +407,10 @@ BDFSXfsInfo* bd_fs_xfs_get_info (const gchar *device, GError **error) {
         val_start++;
         ret->block_size = g_ascii_strtoull (val_start, NULL, 0);
     } else {
-        /* error is already populated */
         g_set_error (error, BD_FS_ERROR, BD_FS_ERROR_PARSE, "Failed to parse xfs file system information");
         g_strfreev (lines);
         bd_fs_xfs_info_free (ret);
-        return FALSE;
+        return NULL;
     }
     while (isdigit (*val_start) || isspace(*val_start))
         val_start++;
@@ -329,11 +419,10 @@ BDFSXfsInfo* bd_fs_xfs_get_info (const gchar *device, GError **error) {
         val_start++;
         ret->block_count = g_ascii_strtoull (val_start, NULL, 0);
     } else {
-        /* error is already populated */
         g_set_error (error, BD_FS_ERROR, BD_FS_ERROR_PARSE, "Failed to parse xfs file system information");
         g_strfreev (lines);
         bd_fs_xfs_info_free (ret);
-        return FALSE;
+        return NULL;
     }
     g_strfreev (lines);
 
@@ -345,9 +434,9 @@ BDFSXfsInfo* bd_fs_xfs_get_info (const gchar *device, GError **error) {
  * @mpoint: the mount point of the file system to resize
  * @new_size: new requested size for the file system *in file system blocks* (see bd_fs_xfs_get_info())
  *            (if 0, the file system is adapted to the underlying block device)
- * @extra: (allow-none) (array zero-terminated=1): extra options for the resize (right now
+ * @extra: (nullable) (array zero-terminated=1): extra options for the resize (right now
  *                                                 passed to the 'xfs_growfs' utility)
- * @error: (out): place to store error (if any)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: whether the file system mounted on @mpoint was successfully resized or not
  *
