@@ -83,37 +83,6 @@ static const UtilDep deps[DEPS_LAST] = {
     {"ndctl", NULL, NULL, NULL},
 };
 
-/**
- * bd_nvdimm_check_deps:
- *
- * Returns: whether the plugin's runtime dependencies are satisfied or not
- *
- * Function checking plugin's runtime dependencies.
- *
- */
-gboolean bd_nvdimm_check_deps (void) {
-    GError *error = NULL;
-    guint i = 0;
-    gboolean status = FALSE;
-    gboolean ret = TRUE;
-
-    for (i=0; i < DEPS_LAST; i++) {
-        status = bd_utils_check_util_version (deps[i].name, deps[i].version,
-                                              deps[i].ver_arg, deps[i].ver_regexp, &error);
-        if (!status)
-            g_warning ("%s", error->message);
-        else
-            g_atomic_int_or (&avail_deps, 1 << i);
-        g_clear_error (&error);
-        ret = ret && status;
-    }
-
-    if (!ret)
-        g_warning("Cannot load the NVDIMM plugin");
-
-    return ret;
-}
-
 /**
  * bd_nvdimm_init:
  *
@@ -144,7 +113,7 @@ void bd_nvdimm_close (void) {
  * bd_nvdimm_is_tech_avail:
  * @tech: the queried tech
  * @mode: a bit mask of queried modes of operation (#BDNVDIMMTechMode) for @tech
- * @error: (out): place to store error (details about why the @tech-@mode combination is not available)
+ * @error: (out) (optional): place to store error (details about why the @tech-@mode combination is not available)
  *
  * Returns: whether the @tech-@mode combination is available -- supported by the
  *          plugin implementation and having all the runtime dependencies available
@@ -169,7 +138,7 @@ gboolean bd_nvdimm_is_tech_avail (BDNVDIMMTech tech, guint64 mode, GError **erro
 /**
  * bd_nvdimm_namespace_get_mode_from_str:
  * @mode_str: string representation of mode
- * @error: (out): place to store error (if any)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: mode matching the @mode_str given or %BD_NVDIMM_NAMESPACE_MODE_UNKNOWN in case of no match
  *
@@ -198,7 +167,7 @@ BDNVDIMMNamespaceMode bd_nvdimm_namespace_get_mode_from_str (const gchar *mode_s
 /**
  * bd_nvdimm_namespace_get_mode_str:
  * @mode: mode to get string representation of
- * @error: (out): place to store error (if any)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: (transfer none): string representation of @mode or %NULL in case of error
  *
@@ -234,7 +203,7 @@ static struct ndctl_namespace* get_namespace_by_name (const gchar *namespace, st
 /**
  * bd_nvdimm_namespace_get_devname:
  * @device: name or path of a block device (e.g. "/dev/pmem0")
- * @error: (out): place to store error (if any)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: (transfer full): namespace device name (e.g. "namespaceX.Y") for @device
  *                           or %NULL if @device is not a NVDIMM namespace
@@ -297,8 +266,8 @@ gchar* bd_nvdimm_namespace_get_devname (const gchar *device, GError **error) {
 /**
  * bd_nvdimm_namespace_enable:
  * @namespace: name of the namespace to enable
- * @extra: (allow-none) (array zero-terminated=1): extra options (currently unused)
- * @error: (out): place to store error (if any)
+ * @extra: (nullable) (array zero-terminated=1): extra options (currently unused)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: whether the @namespace was successfully enabled or not
  *
@@ -338,8 +307,8 @@ gboolean bd_nvdimm_namespace_enable (const gchar *namespace, const BDExtraArg **
 /**
  * bd_nvdimm_namespace_disable:
  * @namespace: name of the namespace to disable
- * @extra: (allow-none) (array zero-terminated=1): extra options (currently unused)
- * @error: (out): place to store error (if any)
+ * @extra: (nullable) (array zero-terminated=1): extra options (currently unused)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: whether the @namespace was successfully disabled or not
  *
@@ -499,8 +468,8 @@ static BDNVDIMMNamespaceInfo* get_nvdimm_namespace_info (struct ndctl_namespace
 /**
  * bd_nvdimm_namespace_info:
  * @namespace: namespace to get information about
- * @extra: (allow-none) (array zero-terminated=1): extra options (currently unused)
- * @error: (out): place to store error (if any)
+ * @extra: (nullable) (array zero-terminated=1): extra options (currently unused)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: (transfer full): information about given namespace or %NULL if no such
  *                           namespace was found (@error may be set to indicate error)
@@ -533,13 +502,13 @@ BDNVDIMMNamespaceInfo* bd_nvdimm_namespace_info (const gchar *namespace, const B
 
 /**
  * bd_nvdimm_list_namespaces:
- * @bus_name: (allow-none): return only namespaces on given bus (specified by name),
+ * @bus_name: (nullable): return only namespaces on given bus (specified by name),
  *                          %NULL may be specified to return namespaces from all buses
- * @region_name: (allow-none): return only namespaces on given region (specified by 'regionX' name),
+ * @region_name: (nullable): return only namespaces on given region (specified by 'regionX' name),
  *                             %NULL may be specified to return namespaces from all regions
  * @idle: whether to list idle (not enabled) namespaces too
- * @extra: (allow-none) (array zero-terminated=1): extra options (currently unused)
- * @error: (out): place to store error (if any)
+ * @extra: (nullable) (array zero-terminated=1): extra options (currently unused)
+ * @error: (out) (optional): place to store error (if any)
  *
  * Returns: (array zero-terminated=1): information about the namespaces on @bus and @region or
  *                                     %NULL if no namespaces were found (@error may be set to indicate error)
@@ -603,10 +572,11 @@ BDNVDIMMNamespaceInfo** bd_nvdimm_list_namespaces (const gchar *bus_name, const
 
 /**
  * bd_nvdimm_namespace_reconfigure:
- * @namespace: name of the namespace to recofigure
+ * @namespace: name of the namespace to reconfigure
  * @mode: mode type to set
- * @error: (out): place to store error if any
- * @extra: (allow-none) (array zero-terminated=1): extra options for the creation (right now
+ * @force: whether to use force to reconfigure an active namespace
+ * @error: (out) (optional): place to store error if any
+ * @extra: (nullable) (array zero-terminated=1): extra options for the creation (right now
  *                                                 passed to the 'ndctl' utility)
  *
  * Returns: whether @namespace was successfully reconfigured or not
@@ -643,15 +613,15 @@ static guint64 pmem_sector_sizes[] = { 512, 4096, 0 };
 static guint64 io_sector_sizes[] = { 0 };
 
 /**
- * bd_nvdimm_namepace_get_supported_sector_sizes:
+ * bd_nvdimm_namespace_get_supported_sector_sizes:
  * @mode: namespace mode
- * @error: (out): place to store error if any
+ * @error: (out) (optional): place to store error if any
  *
  * Returns: (transfer none) (array zero-terminated=1): list of supported sector sizes for @mode
  *
  * Tech category: %BD_NVDIMM_TECH_NAMESPACE-%BD_NVDIMM_TECH_MODE_QUERY
  */
-const guint64 *bd_nvdimm_namepace_get_supported_sector_sizes (BDNVDIMMNamespaceMode mode, GError **error) {
+const guint64 *bd_nvdimm_namespace_get_supported_sector_sizes (BDNVDIMMNamespaceMode mode, GError **error) {
     switch (mode) {
         case BD_NVDIMM_NAMESPACE_MODE_RAW:
         case BD_NVDIMM_NAMESPACE_MODE_MEMORY:
