@@ -4,8 +4,11 @@ import resource
 import overrides_hack
 
 from utils import create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, run_command, run, TestTags, tag_test
-from gi.repository import BlockDev, GLib
 
+import gi
+gi.require_version('GLib', '2.0')
+gi.require_version('BlockDev', '3.0')
+from gi.repository import GLib, BlockDev
 
 class SwapTest(unittest.TestCase):
     requested_plugins = BlockDev.plugin_specs_from_names(("swap",))
@@ -191,21 +194,21 @@ class SwapDepsTest(SwapTest):
 
         with fake_utils("tests/fake_utils/swap_low_version/"):
             # too low version of mkswap available
-            with self.assertRaisesRegexp(GLib.GError, "Too low version of mkswap"):
+            with self.assertRaisesRegex(GLib.GError, "Too low version of mkswap"):
                 BlockDev.swap_is_tech_avail(BlockDev.SwapTech.SWAP, BlockDev.SwapTechMode.CREATE)
 
         with fake_path(all_but="mkswap"):
             # no mkswap available
-            with self.assertRaisesRegexp(GLib.GError, "The 'mkswap' utility is not available"):
+            with self.assertRaisesRegex(GLib.GError, "The 'mkswap' utility is not available"):
                 BlockDev.swap_is_tech_avail(BlockDev.SwapTech.SWAP, BlockDev.SwapTechMode.CREATE)
 
         with fake_path(all_but="swaplabel"):
             # no swaplabel available
-            with self.assertRaisesRegexp(GLib.GError, "The 'swaplabel' utility is not available"):
+            with self.assertRaisesRegex(GLib.GError, "The 'swaplabel' utility is not available"):
                 BlockDev.swap_is_tech_avail(BlockDev.SwapTech.SWAP, BlockDev.SwapTechMode.SET_LABEL)
 
         with fake_path(all_but="mkswap"):
-            with self.assertRaisesRegexp(GLib.GError, "The 'mkswap' utility is not available"):
+            with self.assertRaisesRegex(GLib.GError, "The 'mkswap' utility is not available"):
                 # the device shouldn't matter, the function should return an
                 # error before any other checks or actions
                 BlockDev.swap_mkswap("/dev/device", "LABEL", None)
